diff --git a/CRM/MembershipExtras/Upgrader/Base.php b/CRM/MembershipExtras/Upgrader/Base.php
deleted file mode 100644
index bf4d7119..00000000
--- a/CRM/MembershipExtras/Upgrader/Base.php
+++ /dev/null
@@ -1,396 +0,0 @@
-ctx = array_shift($args);
- $instance->queue = $instance->ctx->queue;
- $method = array_shift($args);
- return call_user_func_array([$instance, $method], $args);
- }
-
- /**
- * CRM_MembershipExtras_Upgrader_Base constructor.
- *
- * @param $extensionName
- * @param $extensionDir
- */
- public function __construct($extensionName, $extensionDir) {
- $this->extensionName = $extensionName;
- $this->extensionDir = $extensionDir;
- }
-
- // ******** Task helpers ********
-
- /**
- * Run a CustomData file.
- *
- * @param string $relativePath
- * the CustomData XML file path (relative to this extension's dir)
- * @return bool
- */
- public function executeCustomDataFile($relativePath) {
- $xml_file = $this->extensionDir . '/' . $relativePath;
- return $this->executeCustomDataFileByAbsPath($xml_file);
- }
-
- /**
- * Run a CustomData file
- *
- * @param string $xml_file
- * the CustomData XML file path (absolute path)
- *
- * @return bool
- */
- protected function executeCustomDataFileByAbsPath($xml_file) {
- $import = new CRM_Utils_Migrate_Import();
- $import->run($xml_file);
- return TRUE;
- }
-
- /**
- * Run a SQL file.
- *
- * @param string $relativePath
- * the SQL file path (relative to this extension's dir)
- *
- * @return bool
- */
- public function executeSqlFile($relativePath) {
- CRM_Utils_File::sourceSQLFile(
- CIVICRM_DSN,
- $this->extensionDir . DIRECTORY_SEPARATOR . $relativePath
- );
- return TRUE;
- }
-
- /**
- * Run the sql commands in the specified file.
- *
- * @param string $tplFile
- * The SQL file path (relative to this extension's dir).
- * Ex: "sql/mydata.mysql.tpl".
- *
- * @return bool
- * @throws \CRM_Core_Exception
- */
- public function executeSqlTemplate($tplFile) {
- // Assign multilingual variable to Smarty.
- $upgrade = new CRM_Upgrade_Form();
-
- $tplFile = CRM_Utils_File::isAbsolute($tplFile) ? $tplFile : $this->extensionDir . DIRECTORY_SEPARATOR . $tplFile;
- $smarty = CRM_Core_Smarty::singleton();
- $smarty->assign('domainID', CRM_Core_Config::domainID());
- CRM_Utils_File::sourceSQLFile(
- CIVICRM_DSN, $smarty->fetch($tplFile), NULL, TRUE
- );
- return TRUE;
- }
-
- /**
- * Run one SQL query.
- *
- * This is just a wrapper for CRM_Core_DAO::executeSql, but it
- * provides syntactic sugar for queueing several tasks that
- * run different queries
- *
- * @return bool
- */
- public function executeSql($query, $params = []) {
- // FIXME verify that we raise an exception on error
- CRM_Core_DAO::executeQuery($query, $params);
- return TRUE;
- }
-
- /**
- * Syntactic sugar for enqueuing a task which calls a function in this class.
- *
- * The task is weighted so that it is processed
- * as part of the currently-pending revision.
- *
- * After passing the $funcName, you can also pass parameters that will go to
- * the function. Note that all params must be serializable.
- */
- public function addTask($title) {
- $args = func_get_args();
- $title = array_shift($args);
- $task = new CRM_Queue_Task(
- [get_class($this), '_queueAdapter'],
- $args,
- $title
- );
- return $this->queue->createItem($task, ['weight' => -1]);
- }
-
- // ******** Revision-tracking helpers ********
-
- /**
- * Determine if there are any pending revisions.
- *
- * @return bool
- */
- public function hasPendingRevisions() {
- $revisions = $this->getRevisions();
- $currentRevision = $this->getCurrentRevision();
-
- if (empty($revisions)) {
- return FALSE;
- }
- if (empty($currentRevision)) {
- return TRUE;
- }
-
- return ($currentRevision < max($revisions));
- }
-
- /**
- * Add any pending revisions to the queue.
- *
- * @param CRM_Queue_Queue $queue
- */
- public function enqueuePendingRevisions(CRM_Queue_Queue $queue) {
- $this->queue = $queue;
-
- $currentRevision = $this->getCurrentRevision();
- foreach ($this->getRevisions() as $revision) {
- if ($revision > $currentRevision) {
- $title = E::ts('Upgrade %1 to revision %2', [
- 1 => $this->extensionName,
- 2 => $revision,
- ]);
-
- // note: don't use addTask() because it sets weight=-1
-
- $task = new CRM_Queue_Task(
- [get_class($this), '_queueAdapter'],
- ['upgrade_' . $revision],
- $title
- );
- $this->queue->createItem($task);
-
- $task = new CRM_Queue_Task(
- [get_class($this), '_queueAdapter'],
- ['setCurrentRevision', $revision],
- $title
- );
- $this->queue->createItem($task);
- }
- }
- }
-
- /**
- * Get a list of revisions.
- *
- * @return array
- * revisionNumbers sorted numerically
- */
- public function getRevisions() {
- if (!is_array($this->revisions)) {
- $this->revisions = [];
-
- $clazz = new ReflectionClass(get_class($this));
- $methods = $clazz->getMethods();
- foreach ($methods as $method) {
- if (preg_match('/^upgrade_(.*)/', $method->name, $matches)) {
- $this->revisions[] = $matches[1];
- }
- }
- sort($this->revisions, SORT_NUMERIC);
- }
-
- return $this->revisions;
- }
-
- public function getCurrentRevision() {
- $revision = CRM_Core_BAO_Extension::getSchemaVersion($this->extensionName);
- if (!$revision) {
- $revision = $this->getCurrentRevisionDeprecated();
- }
- return $revision;
- }
-
- private function getCurrentRevisionDeprecated() {
- $key = $this->extensionName . ':version';
- if ($revision = \Civi::settings()->get($key)) {
- $this->revisionStorageIsDeprecated = TRUE;
- }
- return $revision;
- }
-
- public function setCurrentRevision($revision) {
- CRM_Core_BAO_Extension::setSchemaVersion($this->extensionName, $revision);
- // clean up legacy schema version store (CRM-19252)
- $this->deleteDeprecatedRevision();
- return TRUE;
- }
-
- private function deleteDeprecatedRevision() {
- if ($this->revisionStorageIsDeprecated) {
- $setting = new CRM_Core_BAO_Setting();
- $setting->name = $this->extensionName . ':version';
- $setting->delete();
- CRM_Core_Error::debug_log_message("Migrated extension schema revision ID for {$this->extensionName} from civicrm_setting (deprecated) to civicrm_extension.\n");
- }
- }
-
- // ******** Hook delegates ********
-
- /**
- * @see https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_install
- */
- public function onInstall() {
- $files = glob($this->extensionDir . '/sql/*_install.sql');
- if (is_array($files)) {
- foreach ($files as $file) {
- CRM_Utils_File::sourceSQLFile(CIVICRM_DSN, $file);
- }
- }
- $files = glob($this->extensionDir . '/sql/*_install.mysql.tpl');
- if (is_array($files)) {
- foreach ($files as $file) {
- $this->executeSqlTemplate($file);
- }
- }
- $files = glob($this->extensionDir . '/xml/*_install.xml');
- if (is_array($files)) {
- foreach ($files as $file) {
- $this->executeCustomDataFileByAbsPath($file);
- }
- }
- if (is_callable([$this, 'install'])) {
- $this->install();
- }
- }
-
- /**
- * @see https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_postInstall
- */
- public function onPostInstall() {
- $revisions = $this->getRevisions();
- if (!empty($revisions)) {
- $this->setCurrentRevision(max($revisions));
- }
- if (is_callable([$this, 'postInstall'])) {
- $this->postInstall();
- }
- }
-
- /**
- * @see https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_uninstall
- */
- public function onUninstall() {
- $files = glob($this->extensionDir . '/sql/*_uninstall.mysql.tpl');
- if (is_array($files)) {
- foreach ($files as $file) {
- $this->executeSqlTemplate($file);
- }
- }
- if (is_callable([$this, 'uninstall'])) {
- $this->uninstall();
- }
- $files = glob($this->extensionDir . '/sql/*_uninstall.sql');
- if (is_array($files)) {
- foreach ($files as $file) {
- CRM_Utils_File::sourceSQLFile(CIVICRM_DSN, $file);
- }
- }
- }
-
- /**
- * @see https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
- */
- public function onEnable() {
- // stub for possible future use
- if (is_callable([$this, 'enable'])) {
- $this->enable();
- }
- }
-
- /**
- * @see https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_disable
- */
- public function onDisable() {
- // stub for possible future use
- if (is_callable([$this, 'disable'])) {
- $this->disable();
- }
- }
-
- public function onUpgrade($op, CRM_Queue_Queue $queue = NULL) {
- switch ($op) {
- case 'check':
- return [$this->hasPendingRevisions()];
-
- case 'enqueue':
- return $this->enqueuePendingRevisions($queue);
-
- default:
- }
- }
-
-}
diff --git a/info.xml b/info.xml
index d5f066ad..43aa0998 100755
--- a/info.xml
+++ b/info.xml
@@ -20,10 +20,11 @@
CRM/MembershipExtras
- 22.05.2
+ 23.02.1
+
https://github.com/compucorp/uk.co.compucorp.membershipextras/blob/master/readme.md
@@ -31,5 +32,8 @@
menu-xml@1.0.0
setting-php@1.0.0
+ smarty-v2@1.0.1
+ entity-types-php@1.0.0
+ CRM_MembershipExtras_Upgrader
diff --git a/js/paymentPlanToggler.js b/js/paymentPlanToggler.js
index 2360b965..f30daa90 100644
--- a/js/paymentPlanToggler.js
+++ b/js/paymentPlanToggler.js
@@ -62,7 +62,7 @@ function paymentPlanToggler(togglerValue, currencySymbol) {
function hideOfflineAutorenewField() {
const autoRenewSelector = '.custom-group-offline_autorenew_option';
- waitForElement($, '#customData',
+ waitForElement($, '#customData_Membership',
element => isPaymentPlanTabActive()
? $(autoRenewSelector).show()
: $(autoRenewSelector).hide()
@@ -437,7 +437,7 @@ function paymentPlanToggler(togglerValue, currencySymbol) {
/**
* Prevent the payment tab link from appending hash to the URL
- *
+ *
* This resolves the issue with the activity tab not opening after signing up for a membership.
*/
function preventPaymentTabLinkAction() {
diff --git a/membershipextras.civix.php b/membershipextras.civix.php
index 4367ac71..1cbc43a8 100644
--- a/membershipextras.civix.php
+++ b/membershipextras.civix.php
@@ -24,7 +24,7 @@ class CRM_MembershipExtras_ExtensionUtil {
* Translated text.
* @see ts
*/
- public static function ts($text, $params = []) {
+ public static function ts($text, $params = []): string {
if (!array_key_exists('domain', $params)) {
$params['domain'] = [self::LONG_NAME, NULL];
}
@@ -41,7 +41,7 @@ public static function ts($text, $params = []) {
* Ex: 'http://example.org/sites/default/ext/org.example.foo'.
* Ex: 'http://example.org/sites/default/ext/org.example.foo/css/foo.css'.
*/
- public static function url($file = NULL) {
+ public static function url($file = NULL): string {
if ($file === NULL) {
return rtrim(CRM_Core_Resources::singleton()->getUrl(self::LONG_NAME), '/');
}
@@ -84,27 +84,17 @@ public static function findClass($suffix) {
*
* @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_config
*/
-function _membershipextras_civix_civicrm_config(&$config = NULL) {
+function _membershipextras_civix_civicrm_config($config = NULL) {
static $configured = FALSE;
if ($configured) {
return;
}
$configured = TRUE;
- $template = CRM_Core_Smarty::singleton();
-
$extRoot = __DIR__ . DIRECTORY_SEPARATOR;
- $extDir = $extRoot . 'templates';
-
- if (is_array($template->template_dir)) {
- array_unshift($template->template_dir, $extDir);
- }
- else {
- $template->template_dir = [$extDir, $template->template_dir];
- }
-
$include_path = $extRoot . PATH_SEPARATOR . get_include_path();
set_include_path($include_path);
+ // Based on , this does not currently require mixin/polyfill.php.
}
/**
@@ -114,35 +104,7 @@ function _membershipextras_civix_civicrm_config(&$config = NULL) {
*/
function _membershipextras_civix_civicrm_install() {
_membershipextras_civix_civicrm_config();
- if ($upgrader = _membershipextras_civix_upgrader()) {
- $upgrader->onInstall();
- }
-}
-
-/**
- * Implements hook_civicrm_postInstall().
- *
- * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_postInstall
- */
-function _membershipextras_civix_civicrm_postInstall() {
- _membershipextras_civix_civicrm_config();
- if ($upgrader = _membershipextras_civix_upgrader()) {
- if (is_callable([$upgrader, 'onPostInstall'])) {
- $upgrader->onPostInstall();
- }
- }
-}
-
-/**
- * Implements hook_civicrm_uninstall().
- *
- * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_uninstall
- */
-function _membershipextras_civix_civicrm_uninstall() {
- _membershipextras_civix_civicrm_config();
- if ($upgrader = _membershipextras_civix_upgrader()) {
- $upgrader->onUninstall();
- }
+ // Based on , this does not currently require mixin/polyfill.php.
}
/**
@@ -150,58 +112,9 @@ function _membershipextras_civix_civicrm_uninstall() {
*
* @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
*/
-function _membershipextras_civix_civicrm_enable() {
+function _membershipextras_civix_civicrm_enable(): void {
_membershipextras_civix_civicrm_config();
- if ($upgrader = _membershipextras_civix_upgrader()) {
- if (is_callable([$upgrader, 'onEnable'])) {
- $upgrader->onEnable();
- }
- }
-}
-
-/**
- * (Delegated) Implements hook_civicrm_disable().
- *
- * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_disable
- * @return mixed
- */
-function _membershipextras_civix_civicrm_disable() {
- _membershipextras_civix_civicrm_config();
- if ($upgrader = _membershipextras_civix_upgrader()) {
- if (is_callable([$upgrader, 'onDisable'])) {
- $upgrader->onDisable();
- }
- }
-}
-
-/**
- * (Delegated) Implements hook_civicrm_upgrade().
- *
- * @param $op string, the type of operation being performed; 'check' or 'enqueue'
- * @param $queue CRM_Queue_Queue, (for 'enqueue') the modifiable list of pending up upgrade tasks
- *
- * @return mixed
- * based on op. for 'check', returns array(boolean) (TRUE if upgrades are pending)
- * for 'enqueue', returns void
- *
- * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_upgrade
- */
-function _membershipextras_civix_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
- if ($upgrader = _membershipextras_civix_upgrader()) {
- return $upgrader->onUpgrade($op, $queue);
- }
-}
-
-/**
- * @return CRM_MembershipExtras_Upgrader
- */
-function _membershipextras_civix_upgrader() {
- if (!file_exists(__DIR__ . '/CRM/MembershipExtras/Upgrader.php')) {
- return NULL;
- }
- else {
- return CRM_MembershipExtras_Upgrader_Base::instance();
- }
+ // Based on , this does not currently require mixin/polyfill.php.
}
/**
@@ -220,8 +133,8 @@ function _membershipextras_civix_insert_navigation_menu(&$menu, $path, $item) {
if (empty($path)) {
$menu[] = [
'attributes' => array_merge([
- 'label' => CRM_Utils_Array::value('name', $item),
- 'active' => 1,
+ 'label' => $item['name'] ?? NULL,
+ 'active' => 1,
], $item),
];
return TRUE;
@@ -285,30 +198,3 @@ function _membershipextras_civix_fixNavigationMenuItems(&$nodes, &$maxNavID, $pa
}
}
}
-
-/**
- * (Delegated) Implements hook_civicrm_entityTypes().
- *
- * Find any *.entityType.php files, merge their content, and return.
- *
- * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_entityTypes
- */
-function _membershipextras_civix_civicrm_entityTypes(&$entityTypes) {
- $entityTypes = array_merge($entityTypes, [
- 'CRM_MembershipExtras_DAO_AutoMembershipUpgradeRule' => [
- 'name' => 'AutoMembershipUpgradeRule',
- 'class' => 'CRM_MembershipExtras_DAO_AutoMembershipUpgradeRule',
- 'table' => 'membershipextras_auto_membership_upgrade_rule',
- ],
- 'CRM_MembershipExtras_DAO_ContributionRecurLineItem' => [
- 'name' => 'ContributionRecurLineItem',
- 'class' => 'CRM_MembershipExtras_DAO_ContributionRecurLineItem',
- 'table' => 'membershipextras_subscription_line',
- ],
- 'CRM_MembershipExtras_DAO_PaymentScheme' => [
- 'name' => 'PaymentScheme',
- 'class' => 'CRM_MembershipExtras_DAO_PaymentScheme',
- 'table' => 'civicrm_payment_scheme',
- ],
- ]);
-}
diff --git a/membershipextras.php b/membershipextras.php
index 66db06ea..632f23ff 100755
--- a/membershipextras.php
+++ b/membershipextras.php
@@ -24,24 +24,6 @@ function membershipextras_civicrm_install() {
_membershipextras_civix_civicrm_install();
}
-/**
- * Implements hook_civicrm_postInstall().
- *
- * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_postInstall
- */
-function membershipextras_civicrm_postInstall() {
- _membershipextras_civix_civicrm_postInstall();
-}
-
-/**
- * Implements hook_civicrm_uninstall().
- *
- * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_uninstall
- */
-function membershipextras_civicrm_uninstall() {
- _membershipextras_civix_civicrm_uninstall();
-}
-
/**
* Implements hook_civicrm_enable().
*
@@ -51,24 +33,6 @@ function membershipextras_civicrm_enable() {
_membershipextras_civix_civicrm_enable();
}
-/**
- * Implements hook_civicrm_disable().
- *
- * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_disable
- */
-function membershipextras_civicrm_disable() {
- _membershipextras_civix_civicrm_disable();
-}
-
-/**
- * Implements hook_civicrm_upgrade().
- *
- * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_upgrade
- */
-function membershipextras_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
- return _membershipextras_civix_civicrm_upgrade($op, $queue);
-}
-
/**
* Implements hook_civicrm_navigationMenu().
*
@@ -416,13 +380,6 @@ function membershipextras_civicrm_alterContent(&$content, $context, $tplName, &$
}
}
-/**
- * Implements hook_civicrm_entityTypes().
- */
-function membershipextras_civicrm_entityTypes(&$entityTypes) {
- return _membershipextras_civix_civicrm_entityTypes($entityTypes);
-}
-
function membershipextras_civicrm_preProcess($formName, $form) {
if ($formName === 'CRM_Contribute_Form_ContributionView') {
$preProcessor = new CRM_MembershipExtras_Hook_PreProcess_ContributionView($form);
diff --git a/mixin/entity-types-php@1.0.0.mixin.php b/mixin/entity-types-php@1.0.0.mixin.php
new file mode 100644
index 00000000..8ec4203d
--- /dev/null
+++ b/mixin/entity-types-php@1.0.0.mixin.php
@@ -0,0 +1,36 @@
+addListener('hook_civicrm_entityTypes', function ($e) use ($mixInfo) {
+ // When deactivating on a polyfill/pre-mixin system, listeners may not cleanup automatically.
+ if (!$mixInfo->isActive() || !is_dir($mixInfo->getPath('xml/schema/CRM'))) {
+ return;
+ }
+
+ $files = (array) glob($mixInfo->getPath('xml/schema/CRM/*/*.entityType.php'));
+ foreach ($files as $file) {
+ $entities = include $file;
+ foreach ($entities as $entity) {
+ $e->entityTypes[$entity['class']] = $entity;
+ }
+ }
+ });
+
+};
diff --git a/mixin/smarty-v2@1.0.1.mixin.php b/mixin/smarty-v2@1.0.1.mixin.php
new file mode 100644
index 00000000..5972dbdc
--- /dev/null
+++ b/mixin/smarty-v2@1.0.1.mixin.php
@@ -0,0 +1,51 @@
+getPath('templates');
+ if (!file_exists($dir)) {
+ return;
+ }
+
+ $register = function() use ($dir) {
+ // This implementation has a theoretical edge-case bug on older versions of CiviCRM where a template could
+ // be registered more than once.
+ CRM_Core_Smarty::singleton()->addTemplateDir($dir);
+ };
+
+ // Let's figure out what environment we're in -- so that we know the best way to call $register().
+
+ if (!empty($GLOBALS['_CIVIX_MIXIN_POLYFILL'])) {
+ // Polyfill Loader (v<=5.45): We're already in the middle of firing `hook_config`.
+ if ($mixInfo->isActive()) {
+ $register();
+ }
+ return;
+ }
+
+ if (CRM_Extension_System::singleton()->getManager()->extensionIsBeingInstalledOrEnabled($mixInfo->longName)) {
+ // New Install, Standard Loader: The extension has just been enabled, and we're now setting it up.
+ // System has already booted. New templates may be needed for upcoming installation steps.
+ $register();
+ return;
+ }
+
+ // Typical Pageview, Standard Loader: Defer the actual registration for a moment -- to ensure that Smarty is online.
+ \Civi::dispatcher()->addListener('hook_civicrm_config', function() use ($mixInfo, $register) {
+ if ($mixInfo->isActive()) {
+ $register();
+ }
+ });
+
+};
diff --git a/CRM/MembershipExtras/Upgrader.php b/CRM/MembershipExtras/Upgrader.php
index f2c18830..b02e993d 100755
--- a/CRM/MembershipExtras/Upgrader.php
+++ b/CRM/MembershipExtras/Upgrader.php
@@ -5,7 +5,7 @@
* enabling and disabling the extension. Also includes the code
* to run the upgrade steps defined in Upgrader/Steps/ directory.
*/
-class CRM_MembershipExtras_Upgrader extends CRM_MembershipExtras_Upgrader_Base {
+class CRM_MembershipExtras_Upgrader extends CRM_Extension_Upgrader_Base {
public function postInstall() {
// steps that create new entities.
@@ -78,7 +78,7 @@ public function uninstall() {
}
// To reduce the size of this Upgrader class we move upgraders to Upgrader/Steps folder.
// The functions below override the ones defined in CRM_MembershipExtras_Upgrader_Base file.
// These functions allow Civi to process the upgraders added in the Upgrader/Steps folder
// because without these functions Civi will not process them by default.
@@ -100,26 +100,23 @@ public function hasPendingRevisions() {
/**
* @inheritdoc
*/
- public function enqueuePendingRevisions(CRM_Queue_Queue $queue) {
+ public function enqueuePendingRevisions() {
$currentRevisionNum = (int) $this->getCurrentRevision();
foreach ($this->getRevisions() as $revisionClass => $revisionNum) {
if ($revisionNum <= $currentRevisionNum) {
continue;
}
- $tsParams = [1 => $this->extensionName, 2 => $revisionNum];
- $title = ts('Upgrade %1 to revision %2', $tsParams);
+ $title = ts('Upgrade %1 to revision %2', [
+ 1 => $this->extensionName,
+ 2 => $revisionNum,
+ ]);
$upgradeTask = new CRM_Queue_Task(
[get_class($this), 'runStepUpgrade'],
[(new $revisionClass())],
$title
);
- $queue->createItem($upgradeTask);
- $setRevisionTask = new CRM_Queue_Task(
- [get_class($this), '_queueAdapter'],
- ['setCurrentRevision', $revisionNum],
- $title
- );
- $queue->createItem($setRevisionTask);
+ $this->queue->createItem($upgradeTask);
+ $this->appendTask($title, 'setCurrentRevision', $revisionNum);
}
}
@@ -78,7 +78,7 @@ public function uninstall() {
}
// To reduce the size of this Upgrader class we move upgraders to Upgrader/Steps folder.
- // The functions below override the ones defined in CRM_MembershipExtras_Upgrader_Base file.
+ // The functions below override the ones defined in CRM_Extension_Upgrader_Base file.
// These functions allow Civi to process the upgraders added in the Upgrader/Steps folder
// because without these functions Civi will not process them by default.